@@ -1,6 +1,6 @@
 package Authorize::Rule;
 # ABSTRACT: Rule-based authorization mechanism
-$Authorize::Rule::VERSION = '0.007';
+$Authorize::Rule::VERSION = '0.008';
 use strict;
 use warnings;
 use Carp 'croak';
@@ -101,19 +101,26 @@ sub allowed {
         params   => $req_params,
     );
 
+    my $perms              = $rules->{$entity} || {};
+    my $all_entities_perms = $rules->{''}      || {};
+
     # deny entities that aren't in the rules
-    my $perms = $rules->{$entity}
+    $perms || $all_entities_perms
         or return { %result, action => $default };
 
     # the requested and default
     my $main_ruleset = $perms->{$req_resource} || [];
     my $def_ruleset  = $perms->{''}            || [];
 
+    # perm for all the entities. Lower priority than main&def ruleset
+    # we don't need to check $all_entities_perms->{''} because we have $default
+    my $all_entities_ruleset = $all_entities_perms->{$req_resource} || [];
+
     # if neither, return default action
-    @{ $main_ruleset } || @{ $def_ruleset }
+    @{ $main_ruleset } || @{ $def_ruleset } || @{ $all_entities_ruleset }
         or return { %result, action => $default };
 
-    foreach my $rulesets ( $main_ruleset, $def_ruleset ) {
+    foreach my $rulesets ( $main_ruleset, $def_ruleset, $all_entities_ruleset) {
         my $ruleset_idx = 0;
         my $label;
 
@@ -219,7 +226,7 @@ Authorize::Rule - Rule-based authorization mechanism
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -462,6 +469,23 @@ of a department (or person) given all access to all resources in your company:
         },
     }
 
+=head2 All entities
+
+All entities can access the public resource:
+
+    my $auth = Authorize::Rule->new(
+        default => 0,
+        rules   => {
+            'Person' => {
+                'place' => [ [ 1 ] ]
+            },
+
+            '' => {
+                'public' => [ [ 1 ] ],
+                ''       => [ [ 1 ] ], # ignored, we have a default for that
+            },
+    });
+
 =head2 Per resource
 
 Dogs, however, provide less of a problem. Mostly if you tell them they aren't
@@ -828,7 +852,7 @@ Mickey Nasriachi <mickey@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Sawyer X.
+This software is copyright (c) 2015 by Sawyer X.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
